@@ -1,3 +1,18 @@
+# Copyright (c) 2010-2013 by Yaco Sistemas <ant30tx@gmail.com> or <goinnn@gmail.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this programe.  If not, see <http://www.gnu.org/licenses/>.
+
 from django import VERSION as django_version
 from django.conf import settings
 
@@ -10,15 +25,18 @@ import subprocess
 
 def validate_format(pofile):
     errors = []
-    handle, temp_file = tempfile.mkstemp()
+    handle, temp_file_po = tempfile.mkstemp(suffix='.po')
+    handle, temp_file_mo = tempfile.mkstemp(suffix='.mo')
     os.close(handle)
-    pofile.save(temp_file)
+    pofile.save(temp_file_po)
 
-    cmd = ['msgfmt', '--check-format', temp_file]
+    cmd = ['msgfmt',
+           '--check-format', temp_file_po,
+           '--output-file', temp_file_mo]
     process = subprocess.Popen(cmd, stderr=subprocess.PIPE)
     out, err = process.communicate()
     if process.returncode != 0:
-        input_lines = open(temp_file, 'r').readlines()
+        input_lines = open(temp_file_po, 'r').readlines()
         error_lines = err.strip().split('\n')
         # discard last line since it only says the number of fatal errors
         error_lines = error_lines[:-1]
@@ -34,7 +52,8 @@ def validate_format(pofile):
 
         errors = [format_error_line(line) for line in error_lines]
 
-    os.unlink(temp_file)
+    os.unlink(temp_file_po)
+    os.unlink(temp_file_mo)
     return errors
 
 
